@@ -46,7 +46,7 @@ __mtab_add(char *line)
     return PMOUNT_NOTME;
   }
 
-  fprintf (mtab, line);
+  fprintf (mtab, "%s", line);
 
   if (fclose (mtab) != 0)
     {
@@ -59,7 +59,7 @@ __mtab_add(char *line)
 
 /* Parses mtab and deletes the line that refers to the mount dir 'mntdir'.
    We assume there can't be two lines with same 'mntdir' string. Returns
-   0 is succesful. */
+   0 is successful. */
 int
 __mtab_del (char *mntdir)
 {
@@ -67,6 +67,7 @@ __mtab_del (char *mntdir)
   char line[8192]; /* Yeah; I know this is lame, but it works.
                       Patches welcome. */
   char *ret;
+  int rc;
 
   if (rename (_PATH_MOUNTED, _PATH_MOUNTED "~") == -1)
     if (errno != ENOENT)
@@ -87,7 +88,12 @@ __mtab_del (char *mntdir)
       return PMOUNT_NOTME;
     }
 
-  asprintf (&mntdir, " %s ", mntdir);
+  rc = asprintf (&mntdir, " %s ", mntdir);
+  if (rc < 0)
+    {
+      perror ("asprintf");
+      return PMOUNT_NOTME;
+    }
   while (1)
     {
       ret = fgets (line, sizeof(line), mtab_r);
@@ -99,7 +105,7 @@ __mtab_del (char *mntdir)
           return PMOUNT_NOTME;
         }
       if (strstr (line, mntdir) == NULL)
-        fprintf (mtab_w, ret);
+        fprintf (mtab_w, "%s", ret);
     }
   free (mntdir);
 
